pub struct ProcessingJobClient<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessingJobClient<'a>
impl<'a> ProcessingJobClient<'a>
Sourcepub async fn create_adjust_processing_job(
&self,
license_number: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn create_adjust_processing_job( &self, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
POST CreateAdjustProcessingJob Adjusts the details of existing processing jobs at a Facility, including units of measure and associated packages. Permissions Required:
- Manage Processing Job Parameters:
- body (Option<&Value>): Request body
- license_number (Option
): Filter by licenseNumber
Sourcepub async fn create_processing_job_job_types(
&self,
license_number: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn create_processing_job_job_types( &self, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
POST CreateJobTypes Creates new processing job types for a Facility, including name, category, description, steps, and attributes. Permissions Required:
- Manage Processing Job Parameters:
- body (Option<&Value>): Request body
- license_number (Option
): Filter by licenseNumber
Sourcepub async fn create_processing_job_packages(
&self,
license_number: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn create_processing_job_packages( &self, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
POST CreateProcessingJobPackages Creates packages from processing jobs at a Facility, including optional location and note assignments. Permissions Required:
- Manage Processing Job Parameters:
- body (Option<&Value>): Request body
- license_number (Option
): Filter by licenseNumber
Sourcepub async fn delete_processing_job_job_type_by_id(
&self,
id: &str,
license_number: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn delete_processing_job_job_type_by_id( &self, id: &str, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
DELETE DeleteJobTypeById Archives a Processing Job Type at a Facility, making it inactive for future use. Permissions Required:
- Manage Processing Job Parameters:
- id (str): Path parameter id
- license_number (Option
): Filter by licenseNumber
Sourcepub async fn delete_processing_job_by_id(
&self,
id: &str,
license_number: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn delete_processing_job_by_id( &self, id: &str, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
DELETE DeleteProcessingJobById Archives a Processing Job at a Facility by marking it as inactive and removing it from active use. Permissions Required:
- Manage Processing Job Parameters:
- id (str): Path parameter id
- license_number (Option
): Filter by licenseNumber
Sourcepub async fn finish_processing_job_processing_job(
&self,
license_number: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn finish_processing_job_processing_job( &self, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
PUT FinishProcessingJob Completes processing jobs at a Facility by recording final notes and waste measurements. Permissions Required:
- Manage Processing Job Parameters:
- body (Option<&Value>): Request body
- license_number (Option
): Filter by licenseNumber
Sourcepub async fn get_processing_job_active_job_types(
&self,
last_modified_end: Option<String>,
last_modified_start: Option<String>,
license_number: Option<String>,
page_number: Option<String>,
page_size: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn get_processing_job_active_job_types( &self, last_modified_end: Option<String>, last_modified_start: Option<String>, license_number: Option<String>, page_number: Option<String>, page_size: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
GET GetActiveJobTypes Retrieves a list of all active processing job types defined within a Facility. Permissions Required:
- Manage Processing Job Parameters:
- last_modified_end (Option
): Filter by lastModifiedEnd - last_modified_start (Option
): Filter by lastModifiedStart - license_number (Option
): Filter by licenseNumber - page_number (Option
): Filter by pageNumber - page_size (Option
): Filter by pageSize
Sourcepub async fn get_active_processing_job(
&self,
last_modified_end: Option<String>,
last_modified_start: Option<String>,
license_number: Option<String>,
page_number: Option<String>,
page_size: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn get_active_processing_job( &self, last_modified_end: Option<String>, last_modified_start: Option<String>, license_number: Option<String>, page_number: Option<String>, page_size: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
GET GetActiveProcessingJob Retrieves active processing jobs at a specified Facility. Permissions Required:
- Manage Processing Job Parameters:
- last_modified_end (Option
): Filter by lastModifiedEnd - last_modified_start (Option
): Filter by lastModifiedStart - license_number (Option
): Filter by licenseNumber - page_number (Option
): Filter by pageNumber - page_size (Option
): Filter by pageSize
Sourcepub async fn get_processing_job_inactive_job_types(
&self,
last_modified_end: Option<String>,
last_modified_start: Option<String>,
license_number: Option<String>,
page_number: Option<String>,
page_size: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn get_processing_job_inactive_job_types( &self, last_modified_end: Option<String>, last_modified_start: Option<String>, license_number: Option<String>, page_number: Option<String>, page_size: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
GET GetInactiveJobTypes Retrieves a list of all inactive processing job types defined within a Facility. Permissions Required:
- Manage Processing Job Parameters:
- last_modified_end (Option
): Filter by lastModifiedEnd - last_modified_start (Option
): Filter by lastModifiedStart - license_number (Option
): Filter by licenseNumber - page_number (Option
): Filter by pageNumber - page_size (Option
): Filter by pageSize
Sourcepub async fn get_inactive_processing_job(
&self,
last_modified_end: Option<String>,
last_modified_start: Option<String>,
license_number: Option<String>,
page_number: Option<String>,
page_size: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn get_inactive_processing_job( &self, last_modified_end: Option<String>, last_modified_start: Option<String>, license_number: Option<String>, page_number: Option<String>, page_size: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
GET GetInactiveProcessingJob Retrieves inactive processing jobs at a specified Facility. Permissions Required:
- Manage Processing Job Parameters:
- last_modified_end (Option
): Filter by lastModifiedEnd - last_modified_start (Option
): Filter by lastModifiedStart - license_number (Option
): Filter by licenseNumber - page_number (Option
): Filter by pageNumber - page_size (Option
): Filter by pageSize
Sourcepub async fn get_processing_job_job_types_attributes(
&self,
license_number: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn get_processing_job_job_types_attributes( &self, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
GET GetJobTypesAttributes Retrieves all processing job attributes available for a Facility. Permissions Required:
- Manage Processing Job Parameters:
- license_number (Option
): Filter by licenseNumber
Sourcepub async fn get_processing_job_job_types_categories(
&self,
license_number: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn get_processing_job_job_types_categories( &self, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
GET GetJobTypesCategories Retrieves all processing job categories available for a specified Facility. Permissions Required:
- Manage Processing Job Parameters:
- license_number (Option
): Filter by licenseNumber
Sourcepub async fn get_processing_job_by_id(
&self,
id: &str,
license_number: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn get_processing_job_by_id( &self, id: &str, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
GET GetProcessingJobById Retrieves a ProcessingJob by Id. Permissions Required:
- Manage Processing Job Parameters:
- id (str): Path parameter id
- license_number (Option
): Filter by licenseNumber
Sourcepub async fn start_processing_job_processing_job(
&self,
license_number: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn start_processing_job_processing_job( &self, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
POST StartProcessingJob Initiates new processing jobs at a Facility, including job details and associated packages. Permissions Required:
- Manage Processing Job Parameters:
- body (Option<&Value>): Request body
- license_number (Option
): Filter by licenseNumber
Sourcepub async fn unfinish_processing_job_processing_job(
&self,
license_number: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn unfinish_processing_job_processing_job( &self, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
PUT UnfinishProcessingJob Reopens previously completed processing jobs at a Facility to allow further updates or corrections. Permissions Required:
- Manage Processing Job Parameters:
- body (Option<&Value>): Request body
- license_number (Option
): Filter by licenseNumber
Sourcepub async fn update_processing_job_job_types(
&self,
license_number: Option<String>,
body: Option<&Value>,
) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
pub async fn update_processing_job_job_types( &self, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>
PUT UpdateJobTypes Updates existing processing job types at a Facility, including their name, category, description, steps, and attributes. Permissions Required:
- Manage Processing Job Parameters:
- body (Option<&Value>): Request body
- license_number (Option
): Filter by licenseNumber